#!/usr/bin/env node
'use strict';

/******************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

var __assign = function() {
    __assign = Object.assign || function __assign(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p)) t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};

function __awaiter(thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
}

function __generator(thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (g && (g = 0, op[0] && (_ = 0)), _) try {
            if (f = 1, y && (t = op[0] & 2 ? y["return"] : op[0] ? y["throw"] || ((t = y["return"]) && t.call(y), 0) : y.next) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [op[0] & 2, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
}

/**
 * Example Usage:
 *
 * const client = RESTClient.forNoAuth(baseUrl);
 * const client = RESTClient.forBasicAuth(baseUrl, "user", "pass");
 * const client = RESTClient.forBearerToken(baseUrl, "token");
 *
 * client.defaultHeaders["accept"] = "application/json";
 */
var RESTClient = /** @class */ (function () {
    function RESTClient(baseUrl) {
        this.authHandler = {
            getAuthHeader: function () { return ""; },
            getAuthToken: function () { return ""; },
            addAuthHeader: function (headers) { return headers; }
        };
        this.defaultHeaders = {};
        this.defaultOptions = {};
        // Remove any trailing slashes...
        baseUrl = baseUrl.replace(/\/+$/, "");
        this.baseUrl = baseUrl;
    }
    RESTClient.forNoAuth = function (baseUrl) {
        return new RESTClient(baseUrl);
    };
    //
    // CORE METHODS
    //
    // Returns the authHeader that is configured...
    RESTClient.prototype.getAuthHeader = function () { return this.authHandler.getAuthHeader(); };
    // Returns the authToken that is configured...
    RESTClient.prototype.getAuthToken = function () { return this.authHandler.getAuthToken(); };
    // Perform a generic, authenticated request...
    RESTClient.prototype.fetch = function (method, url, authHeader, otherHeaders, body) {
        if (authHeader === void 0) { authHeader = ""; }
        if (otherHeaders === void 0) { otherHeaders = {}; }
        if (body === void 0) { body = ""; }
        return __awaiter(this, void 0, void 0, function () {
            var headers, options, rawResponse;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        headers = __assign({}, this.defaultHeaders);
                        // Add authentication. If passed in, use that. Otherwise, use the IAuthHandler...
                        if (authHeader) {
                            headers["authorization"] = authHeader;
                        }
                        else {
                            headers = this.authHandler.addAuthHeader(headers);
                        }
                        // Add any additional headers that were passed in...
                        headers = __assign(__assign({}, headers), otherHeaders);
                        options = __assign({}, this.defaultOptions);
                        options["method"] = method;
                        options["headers"] = headers;
                        if (body) {
                            options["body"] = body;
                        }
                        return [4 /*yield*/, fetch(url, options)];
                    case 1:
                        rawResponse = _a.sent();
                        return [2 /*return*/, rawResponse];
                }
            });
        });
    };
    // Fetch data and convert to JSON...
    RESTClient.prototype.fetchJson = function (method, url, authHeader, otherHeaders, body) {
        if (authHeader === void 0) { authHeader = ""; }
        if (otherHeaders === void 0) { otherHeaders = {}; }
        if (body === void 0) { body = ""; }
        return __awaiter(this, void 0, void 0, function () {
            var rawResponse;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.fetch(method, url, authHeader, otherHeaders, body)];
                    case 1:
                        rawResponse = _a.sent();
                        return [2 /*return*/, rawResponse.json()];
                }
            });
        });
    };
    // Fetch data and convert to text...
    RESTClient.prototype.fetchText = function (method, url, authHeader, otherHeaders, body) {
        if (authHeader === void 0) { authHeader = ""; }
        if (otherHeaders === void 0) { otherHeaders = {}; }
        if (body === void 0) { body = ""; }
        return __awaiter(this, void 0, void 0, function () {
            var rawResponse;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.fetch(method, url, authHeader, otherHeaders, body)];
                    case 1:
                        rawResponse = _a.sent();
                        return [2 /*return*/, rawResponse.text()];
                }
            });
        });
    };
    // Fetch data and convert to a blob...
    RESTClient.prototype.fetchBlob = function (method, url, authHeader, otherHeaders, body) {
        if (authHeader === void 0) { authHeader = ""; }
        if (otherHeaders === void 0) { otherHeaders = {}; }
        if (body === void 0) { body = ""; }
        return __awaiter(this, void 0, void 0, function () {
            var rawResponse;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.fetch(method, url, authHeader, otherHeaders, body)];
                    case 1:
                        rawResponse = _a.sent();
                        return [2 /*return*/, rawResponse.blob()];
                }
            });
        });
    };
    // Fetch data and convert to JSON or text. Or, if it fails, return the raw response...
    // NOTE: This was having issues with NodeJS. I found this issue describing it: https://github.com/node-fetch/node-fetch/issues/1131
    // It would just hang after cloning and eventually timeout
    RESTClient.prototype.fetchJsonOrText = function (method, url, authHeader, otherHeaders, body) {
        if (authHeader === void 0) { authHeader = ""; }
        if (otherHeaders === void 0) { otherHeaders = {}; }
        if (body === void 0) { body = ""; }
        return __awaiter(this, void 0, void 0, function () {
            var rawResponse, responseCopy;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0: return [4 /*yield*/, this.fetch(method, url, authHeader, otherHeaders, body)];
                    case 1:
                        rawResponse = _a.sent();
                        responseCopy = rawResponse.clone();
                        return [2 /*return*/, rawResponse.json().then(function (jsonResponse) { return jsonResponse; })
                                .catch(function (error) {
                                return responseCopy.text()
                                    .then(function (textResponse) { return textResponse; })
                                    .catch(function (error) { return rawResponse; });
                            })];
                }
            });
        });
    };
    // Perform a GET request...
    RESTClient.prototype.get = function (url, authHeader, otherHeaders) {
        if (authHeader === void 0) { authHeader = ""; }
        if (otherHeaders === void 0) { otherHeaders = {}; }
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.fetch("GET", url, authHeader, otherHeaders)];
            });
        });
    };
    // Perform a POST request...
    RESTClient.prototype.post = function (url, authHeader, otherHeaders, body) {
        if (authHeader === void 0) { authHeader = ""; }
        if (otherHeaders === void 0) { otherHeaders = {}; }
        if (body === void 0) { body = ""; }
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.fetch("POST", url, authHeader, otherHeaders, body)];
            });
        });
    };
    // Perform a PUT request...
    RESTClient.prototype.put = function (url, authHeader, otherHeaders, body) {
        if (authHeader === void 0) { authHeader = ""; }
        if (otherHeaders === void 0) { otherHeaders = {}; }
        if (body === void 0) { body = ""; }
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.fetch("PUT", url, authHeader, otherHeaders, body)];
            });
        });
    };
    // Perform a DELETE request...
    RESTClient.prototype.delete = function (url, authHeader, otherHeaders) {
        if (authHeader === void 0) { authHeader = ""; }
        if (otherHeaders === void 0) { otherHeaders = {}; }
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.fetch("DELETE", url, authHeader, otherHeaders)];
            });
        });
    };
    // Perform a PATCH request...
    RESTClient.prototype.patch = function (url, authHeader, otherHeaders, body) {
        if (authHeader === void 0) { authHeader = ""; }
        if (otherHeaders === void 0) { otherHeaders = {}; }
        if (body === void 0) { body = ""; }
        return __awaiter(this, void 0, void 0, function () {
            return __generator(this, function (_a) {
                return [2 /*return*/, this.fetch("PATCH", url, authHeader, otherHeaders, body)];
            });
        });
    };
    return RESTClient;
}());

var PlasmaProjectsApiClient = /** @class */ (function () {
    function PlasmaProjectsApiClient(baseUrl, plasmaApiKey) {
        this._baseUrl = baseUrl;
        this._plasmaApiKey = plasmaApiKey;
        this._restClient = new RESTClient(baseUrl);
    }
    PlasmaProjectsApiClient.prototype.createProject = function (projectName, projectDescription, projectType, returnToUrl) {
        return __awaiter(this, void 0, void 0, function () {
            var url, project;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        url = "".concat(this._baseUrl, "/api/plasma/projects/project?plasmaApiKey=").concat(encodeURIComponent(this._plasmaApiKey));
                        project = {
                            name: projectName,
                            description: projectDescription,
                            projectType: projectType,
                            returnToUrl: returnToUrl
                        };
                        return [4 /*yield*/, this._restClient.fetchJson("POST", url, undefined, { "Content-Type": "application/json" }, JSON.stringify(project))];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            });
        });
    };
    PlasmaProjectsApiClient.prototype.createPlatform = function (projectId, name, platformType, clientId, privateKey, clientSecret, scope, siteId) {
        return __awaiter(this, void 0, void 0, function () {
            var url, platform;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        url = "".concat(this._baseUrl, "/api/plasma/projects/platform?plasmaApiKey=").concat(encodeURIComponent(this._plasmaApiKey), "&projectId=").concat(projectId);
                        platform = {
                            name: name,
                            platformType: platformType,
                            clientId: clientId,
                            privateKey: privateKey,
                            clientSecret: clientSecret,
                            scope: scope,
                            siteId: siteId
                        };
                        return [4 /*yield*/, this._restClient.fetchJson("POST", url, undefined, { "Content-Type": "application/json" }, JSON.stringify(platform))];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            });
        });
    };
    PlasmaProjectsApiClient.prototype.createEnvironment = function (projectId, platformId, name, fhirUrl, authUrl, tokenUrl) {
        return __awaiter(this, void 0, void 0, function () {
            var url, environment;
            return __generator(this, function (_a) {
                switch (_a.label) {
                    case 0:
                        url = "".concat(this._baseUrl, "/api/plasma/projects/environment?plasmaApiKey=").concat(encodeURIComponent(this._plasmaApiKey), "&projectId=").concat(projectId);
                        environment = {
                            platformId: platformId,
                            name: name,
                            fhirUrl: fhirUrl,
                            authUrl: authUrl,
                            tokenUrl: tokenUrl
                        };
                        return [4 /*yield*/, this._restClient.fetchJson("POST", url, undefined, { "Content-Type": "application/json" }, JSON.stringify(environment))];
                    case 1: return [2 /*return*/, _a.sent()];
                }
            });
        });
    };
    return PlasmaProjectsApiClient;
}());

var path$1 = require("path");
var fse$1 = require("fs-extra");
/**
 * Create the directory at "dir" relative to the current working directory.
 * Returns true/false if it was successful.
 */
function createDirectory(dir) {
    return __awaiter(this, void 0, void 0, function () {
        var projectDir, relativeProjectDir, projectDirIsCurrentDir;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    projectDir = path$1.resolve(process.cwd(), dir);
                    relativeProjectDir = path$1.relative(process.cwd(), projectDir);
                    projectDirIsCurrentDir = relativeProjectDir === "";
                    if (!!projectDirIsCurrentDir) return [3 /*break*/, 3];
                    if (!fse$1.existsSync(projectDir)) return [3 /*break*/, 1];
                    console.log("\uFE0F\"".concat(relativeProjectDir, "\" already exists. Please try again with a different directory."));
                    return [2 /*return*/, false];
                case 1: return [4 /*yield*/, fse$1.mkdir(projectDir)];
                case 2:
                    _a.sent();
                    return [2 /*return*/, true];
                case 3: return [2 /*return*/, false];
            }
        });
    });
}
/**
 * Tries to read a file into a string and returns data about what happened
 * (Used for reading private key)
 */
function tryReadFileContents(file) {
    // Check if file exists...
    if (!fse$1.existsSync(file)) {
        return { success: false, contents: "", errorMessage: "File does not exist: ".concat(file) };
    }
    try {
        var contents = fse$1.readFileSync(file, "utf8");
        return { success: true, contents: contents, errorMessage: "" };
    }
    catch (err) {
        return { success: false, contents: "", errorMessage: "Unable to read file: ".concat(file) };
    }
}
// Writes the .npmrc file in the given directory
function writeNPMRC(dir) {
    return __awaiter(this, void 0, void 0, function () {
        var lines, npmrcFile;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    lines = [
                        "registry=https://registry.npmjs.org/",
                    ];
                    npmrcFile = path$1.resolve(dir, ".npmrc");
                    if (!!fse$1.existsSync(npmrcFile)) return [3 /*break*/, 2];
                    return [4 /*yield*/, fse$1.writeFile(npmrcFile, lines.join("\n"))];
                case 1:
                    _a.sent();
                    return [2 /*return*/, true];
                case 2: 
                // Clear .npmrc file and write all lines to it...
                return [4 /*yield*/, fse$1.truncate(npmrcFile, 0)];
                case 3:
                    // Clear .npmrc file and write all lines to it...
                    _a.sent();
                    return [4 /*yield*/, fse$1.writeFile(npmrcFile, lines.join("\n"))];
                case 4:
                    _a.sent();
                    return [2 /*return*/, true];
            }
        });
    });
}
// Writes the .env file in the given directory
function writeEnvFile(dir, envContents) {
    return __awaiter(this, void 0, void 0, function () {
        var envFile;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    envFile = path$1.resolve(dir, ".env");
                    if (!!fse$1.existsSync(envFile)) return [3 /*break*/, 2];
                    return [4 /*yield*/, fse$1.writeFile(envFile, envContents)];
                case 1:
                    _a.sent();
                    return [2 /*return*/, true];
                case 2: 
                // Clear .env file and write all lines to it...
                return [4 /*yield*/, fse$1.truncate(envFile, 0)];
                case 3:
                    // Clear .env file and write all lines to it...
                    _a.sent();
                    return [4 /*yield*/, fse$1.writeFile(envFile, envContents)];
                case 4:
                    _a.sent();
                    return [2 /*return*/, true];
            }
        });
    });
}
/**
 * Copy the template at the {templateDirectory} into the {targetDirectory}
 * Also writes the .npmrc file in the target directory
 * @param templateDirectory Template directory, relative to the "templates" directory. Example: "nextjs-patient-search-example"
 * @param targetDirectory Directory to copy template into
 */
function copyTemplate(templateDirectory, targetDirectory) {
    return __awaiter(this, void 0, void 0, function () {
        var projectDir, sharedTemplate, e_1;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    projectDir = path$1.resolve(process.cwd(), targetDirectory);
                    sharedTemplate = path$1.resolve(__dirname, "templates", templateDirectory);
                    _a.label = 1;
                case 1:
                    _a.trys.push([1, 4, , 5]);
                    return [4 /*yield*/, fse$1.copy(sharedTemplate, projectDir)];
                case 2:
                    _a.sent();
                    // Add the .npmrc file...
                    return [4 /*yield*/, writeNPMRC(projectDir)];
                case 3:
                    // Add the .npmrc file...
                    _a.sent();
                    return [3 /*break*/, 5];
                case 4:
                    e_1 = _a.sent();
                    console.error(e_1);
                    return [2 /*return*/, false];
                case 5: return [2 /*return*/, true];
            }
        });
    });
}

/**
 * Get a freetext-style input
 * @param name Name of variable to assign response to
 * @param message Prompt for the user
 * @param defaultVal Default value (or undefined)
 * @param when Function that returns true when this should be shown
 */
function getInputQuestion(name, message, defaultVal, when) {
    return {
        type: "input", name: name, message: message, default: defaultVal, when: when
    };
}
/**
 * Gets a question where a user must choose from a list
 * @param name Name of variable to assign response to
 * @param message Prompt for the user
 * @param values Array of values. Or a function that can take the "answers" and return an array of values
 * @returns
 */
function getListQuestion(name, message, values, when) {
    var choices = (typeof values === "function")
        ? function (answers) { return values(answers); }
        : values;
    return {
        type: "list", name: name, message: message, choices: choices, when: when, default: [],
        filter: function (val) { return val; }
    };
}
function getCheckboxQuestion(name, message, values, when) {
    var choices = values;
    return {
        type: "checkbox", name: name, message: message, choices: choices,
        filter: function (val) { return val; }
    };
}

var SMART_BACKEND_CONSOLE_CODE_SNIPPET = "\n    //\n    // SMART\n    //\n\n    console.log(\"\");\n    console.log(\"Connecting to SMART...\");\n    let respConnect = await plasma.backendConnect(PLASMA_PROJECT_ID, PLASMA_ENV_SMARTHEALTHIT, PLASMA_CLIENT_SECRET);\n    if (respConnect.error) { console.log(respConnect.error); return; }\n    patient = await plasma.readPatient(FhirRecords.smart.smart_health_it_backend_sandbox.Patient.GerardoBotello.fhirId);\n    if (patient.name && patient.name[0]) {\n        console.log(\"Found Patient: \");\n        console.log(Resources.r4.HumanName.toString(patient.name[0]));\n    }\n\n    vitals = await plasma.readVitals(patient.id!);\n    if (vitals && vitals.length > 0) {\n        console.log(\"Found Vitals: \");\n        console.log(Resources.r4.Observation.toString(vitals[0]));\n        //console.log(JSON.stringify(vitals[0], null, 2));\n    }\n";
var EPIC_BACKEND_CONSOLE_CODE_SNIPPET = "\n    //\n    // EPIC\n    //\n\n    console.log(\"\");\n    console.log(\"Connecting to Epic...\");\n    respConnect = await plasma.backendConnect(PLASMA_PROJECT_ID, PLASMA_ENV_EPIC, PLASMA_CLIENT_SECRET);\n    if (respConnect.error) { console.log(respConnect.error); return; }\n    patient = await plasma.readPatient(FhirRecords.epic.epic_sandbox.Patient.TheodoreMyChart.fhirId);\n    if (patient.name && patient.name[0]) {\n        console.log(\"Found Patient: \");\n        console.log(Resources.r4.HumanName.toString(patient.name[0]));\n    }\n    vitals = await plasma.readVitals(patient.id!);\n    if (vitals && vitals.length > 0) {\n        console.log(\"Found Vitals: \");\n        console.log(Resources.r4.Observation.toString(vitals[0]));\n        //console.log(JSON.stringify(vitals[0], null, 2));\n    }\n";
// Returns the code to display a launch button on the landing page (like the button you click to launch with a specific EHR)
function getLaunchTableRow(text, plasmaBaseUrl, projectId, environmentId, color) {
    return "\n                <LaunchTableRow text=\"".concat(text, "\"\n                    href=\"").concat(plasmaBaseUrl, "/api/plasma/sof/launch?projectId=").concat(projectId, "&environmentId=").concat(environmentId, "\"\n                    buttonStyles=\"my-3 inline-flex items-center py-2 px-3 text-sm font-medium text-center text-white bg-").concat(color, "-700 rounded-lg hover:bg-").concat(color, "-800 focus:ring-4 focus:ring-").concat(color, "-300\" \n                />\n");
}

/**
 * Plasma CLI
 *
 * Uses Inquirer to ask the user some questions and generate a templated Plasma app
 *
 * Usage:
 * npx create-plasma-app [dir] [plasmaApiKey]
 */
// TODO Items:
// 1. Make it more generic. Examples...
//      - returnToUrl is hard-coded
//      - Have to put in custom stuff for each template
//      - Custom scopes per EHR
//      - .env file has NEXT_PUBLIC_ hardcoded prefix
var path = require("path");
var fse = require("fs-extra");
var process$1 = require("process");
var execSync = require("child_process").execSync;
var inquirer = require("inquirer");
var chalk = require("chalk");
var PLASMA_BASE_URL = "https://plasma.smart-on-fhir.com";
var USER_CONTEXT_PATIENT = "Patient";
var USER_CONTEXT_CLINICIAN = "Clinician";
var USER_CONTEXT_BACKEND = "Backend";
var DEVICE_PLATFORM_WEB = "Web";
var DEVICE_PLATFORM_MOBILE = "Mobile";
var DEVICE_PLATFORM_SERVER = "Server";
var EHR_PLATFORM_SMART = "SmartHealthIT";
var EHR_PLATFORM_EPIC = "Epic";
// Health System IDs...
var HEALTH_SYSTEM_ID_SMART_SANDBOX = "SMART_BackendSandbox";
var HEALTH_SYSTEM_ID_SMART_SANDBOX_PATIENT = "SMART_PatientSandbox";
var HEALTH_SYSTEM_ID_SMART_SANDBOX_CLINICIAN = "SMART_ClinicianSandbox";
var HEALTH_SYSTEM_ID_EPIC_SANDBOX = "Epic_Sandbox";
var templates = [
    {
        id: "nextjs-blank-web-app-example",
        name: "Blank Web App (NextJS)",
        userTypes: [USER_CONTEXT_PATIENT, USER_CONTEXT_CLINICIAN],
        deviceTypes: [DEVICE_PLATFORM_WEB],
        needsEnvFile: true,
        needsNpmrcFile: true,
        needsLaunchRows: true,
        installScript: "npm install",
        templateDirectory: "nextjs-blank-web-app-example",
        defaultScopes: "patient/*.* user/*.* openid fhirUser profile offline_access launch launch/patient",
        scopesByEhrPlatform: {
            EHR_PLATFORM_EPIC: "patient/*.* user/*.* openid fhirUser profile offline_access launch launch/patient"
        },
    },
    {
        id: "nextjs-risk-score-diabetes",
        name: "Diabetes Risk Score (NextJS)",
        userTypes: [USER_CONTEXT_PATIENT, USER_CONTEXT_CLINICIAN],
        deviceTypes: [DEVICE_PLATFORM_WEB],
        needsEnvFile: true,
        needsNpmrcFile: true,
        needsLaunchRows: true,
        installScript: "npm install",
        templateDirectory: "nextjs-risk-score-diabetes",
        defaultScopes: "patient/*.* user/*.* openid fhirUser profile offline_access launch launch/patient",
        scopesByEhrPlatform: {
            EHR_PLATFORM_EPIC: "patient/*.* user/*.* openid fhirUser profile offline_access launch launch/patient"
        },
    },
    {
        id: "nodejs-console-app-example",
        name: "Console App (NodeJS)",
        userTypes: [USER_CONTEXT_BACKEND],
        deviceTypes: [DEVICE_PLATFORM_SERVER],
        needsEnvFile: true,
        needsNpmrcFile: true,
        needsLaunchRows: false,
        installScript: "npm install",
        templateDirectory: "nodejs-console-app-example",
        defaultScopes: "launch launch/patient patient/*.read offline_access",
        scopesByEhrPlatform: {
            EHR_PLATFORM_EPIC: ""
        },
    },
];
// Run the process...
run().then(function () { process$1.exit(0); }, function (error) {
    console.error(error);
    process$1.exit(1);
});
// create-plasma-app...
function run() {
    return __awaiter(this, void 0, void 0, function () {
        var packageJson, version, dir, plasmaApiKey, questions, art, answers, tempAnswer, template, projectDir, templateDirectory, success, srcTempDir, srcDir, projectData, envContents;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0: return [4 /*yield*/, fse.readJson(path.join(__dirname, "..", "package.json"))];
                case 1:
                    packageJson = _a.sent();
                    version = packageJson.version;
                    dir = "";
                    plasmaApiKey = "";
                    if (process$1.argv.length > 2) {
                        dir = process$1.argv[2];
                    }
                    if (process$1.argv.length > 3) {
                        plasmaApiKey = process$1.argv[3];
                    }
                    questions = [
                        // Directory...
                        getInputQuestion("dir", "Where would you like to create your app?", "./my-plasma-app", function () { return (dir === ""); }),
                        // Patient/Clinician/Backend...
                        getListQuestion("userContext", "Who will be using this app?", [USER_CONTEXT_BACKEND, USER_CONTEXT_PATIENT, USER_CONTEXT_CLINICIAN]),
                        // Web/Mobile/Server...
                        getListQuestion("devicePlatform", "What type of app is this?", function (answers) { return getDevicePlatformOptions(answers.userContext); }, function (answers) { return true; }),
                        // Blank/Console/Patient Search/Diabetes...
                        getListQuestion("templateId", "Which template would you like to start with?", function (answers) { return getTemplateTypeOptions(answers.userContext, answers.devicePlatform); }, function (answers) { return true; }),
                        // Epic/Cerner/AthenaHealth/NextGen/AllScripts/Other...
                        getCheckboxQuestion("platforms", "Which additional platform(s) do you want to support?\nPlease note: A default platform will be added automatically.\n", getEhrPlatformOptions()),
                        // Use Plasma Account...
                        { type: "confirm", name: "havePlasmaAccount", message: "Do you have a Plasma account? (Choose No if you don't want to configure anything with Plasma)", default: (plasmaApiKey !== ""), when: function () { return (plasmaApiKey === ""); } },
                        // Instance of Plasma (https://plasma.smart-on-fhir.com)...
                        getInputQuestion("plasmaInstance", "Where is your instance of Plasma hosted?", "https://plasma.smart-on-fhir.com", function (answers) { return (answers.havePlasmaAccount) || (plasmaApiKey !== ""); }),
                        // Plasma Projects API Key...
                        getInputQuestion("plasmaProjectsApiKey", "What is your Plasma Projects API Key?", "", function (answers) { return (answers.havePlasmaAccount) && (plasmaApiKey === ""); }),
                        // Client IDs for all EHRs...
                        getInputQuestion("clientId_Epic", "What is your Epic Client ID (Non-Production)?", "", function (answers) { return answers.platforms.includes(EHR_PLATFORM_EPIC); }),
                        // Secrets for all EHRs (BACKEND ONLY)...
                        getInputQuestion("privateKey_Epic", "What is the path to your Epic private key file?", "", function (answers) { return answers.platforms.includes(EHR_PLATFORM_EPIC) && answers.userContext === USER_CONTEXT_BACKEND; }),
                    ];
                    art = "\n                                         _.oo.\n                 _.u[[/;:,.         .odMMMMMM'\n              .o888UU[[[/;:-.  .o@P^    MMM^\n             oN88888UU[[[/;::-.        dP^\n            dNMMNN888UU[[[/;:--.   .o@P^\n           ,MMMMMMN888UU[[/;::-. o@^\n           NNMMMNN888UU[[[/~.o@P^\n           888888888UU[[[/o@^-..\n          oI8888UU[[[/o@P^:--..\n       .@^  YUU[[[/o@^;::---..\n     oMP     ^/o@P^;:::---..\n  .dMMM    .o@^ ^;::---...\n dMMMMMMM@^`       `^^^^\nYMMMUP^\n ^^\n";
                    // Prompt user...
                    console.log("");
                    console.log(chalk.hex('#800080')(art));
                    console.log(chalk.hex('#FF0000')("🔥🔥 Welcome to Plasma! Let's create a new project! 🔥🔥"));
                    console.log("Version: " + version);
                    console.log("");
                    return [4 /*yield*/, inquirer.prompt(questions)];
                case 2:
                    answers = _a.sent();
                    if (!(answers.platforms.includes(EHR_PLATFORM_EPIC) && answers.userContext === USER_CONTEXT_BACKEND)) return [3 /*break*/, 5];
                    _a.label = 3;
                case 3:
                    if (!(!fse.existsSync(answers.privateKey_Epic) && answers.privateKey_Epic !== "")) return [3 /*break*/, 5];
                    return [4 /*yield*/, inquirer.prompt(getInputQuestion("privateKey_Epic", "".concat(answers.privateKey_Epic, " doesn't exist, please re-enter the path to your Epic private key file."), ""))];
                case 4:
                    tempAnswer = _a.sent();
                    answers.privateKey_Epic = tempAnswer.privateKey_Epic;
                    return [3 /*break*/, 3];
                case 5:
                    // Set some defaults since some questions get skipped...
                    if (!answers.dir) {
                        answers.dir = dir;
                    } // Add directory if it was specified in the arguments...
                    if (!answers.havePlasmaAccount) {
                        answers.havePlasmaAccount = (plasmaApiKey !== "");
                    } // Add Plasma Account if it was specified in the arguments...
                    if (!answers.plasmaProjectsApiKey) {
                        answers.plasmaProjectsApiKey = plasmaApiKey;
                    } // Add Plasma Projects API Key if it was specified in the arguments...
                    if (!answers.platforms.includes(EHR_PLATFORM_SMART)) {
                        answers.platforms.unshift(EHR_PLATFORM_SMART);
                    } // Always add SMART-Health-IT to every template...
                    // TODO: Make constants for DEFAULT_DEVICE_PLATFORM and DEFAULT_TEMPLATE_TYPE...
                    if (!answers.devicePlatform) {
                        answers.devicePlatform = DEVICE_PLATFORM_SERVER;
                    } // Default to server if not specified...
                    if (!answers.templateId) {
                        answers.templateId = "nodejs-console-app-example";
                    } // Default to console app if not specified...
                    template = templates.find(function (template) { return template.id === answers.templateId; });
                    projectDir = path.resolve(process$1.cwd(), answers.dir);
                    templateDirectory = template.templateDirectory;
                    if (!templateDirectory) {
                        console.error("Template not found!");
                        process$1.exit(1);
                    }
                    return [4 /*yield*/, createDirectory(answers.dir)];
                case 6:
                    success = _a.sent();
                    if (!success) {
                        process$1.exit(1);
                    }
                    return [4 /*yield*/, copyTemplate(templateDirectory, answers.dir)];
                case 7:
                    // Copy the template...
                    success = _a.sent();
                    if (!success) {
                        console.log("Could not process template");
                        process$1.exit(1);
                    }
                    srcTempDir = path.join(projectDir, "src-temp");
                    srcDir = path.join(projectDir, "src");
                    if (fse.existsSync(srcTempDir) && !fse.existsSync(srcDir)) {
                        fse.renameSync(srcTempDir, srcDir);
                    }
                    if (fse.existsSync(srcTempDir)) {
                        fse.removeSync(srcTempDir);
                    }
                    if (!answers.havePlasmaAccount) return [3 /*break*/, 17];
                    // Create project/platforms/environments...
                    console.log("Creating Plasma project records...");
                    return [4 /*yield*/, createProjectAndEnvironments(answers, answers.plasmaInstance, answers.plasmaProjectsApiKey, answers.userContext, answers.platforms)];
                case 8:
                    projectData = _a.sent();
                    if (!template.needsEnvFile) return [3 /*break*/, 10];
                    console.log("Writing .env file...");
                    envContents = getEnvFileContents(answers.plasmaInstance, answers.userContext, projectData);
                    return [4 /*yield*/, writeEnvFile(projectDir, envContents)];
                case 9:
                    _a.sent();
                    _a.label = 10;
                case 10:
                    if (!template.needsNpmrcFile) return [3 /*break*/, 12];
                    console.log("Writing .npmrc file...");
                    return [4 /*yield*/, writeNPMRC(projectDir)];
                case 11:
                    _a.sent();
                    _a.label = 12;
                case 12:
                    if (!template.needsLaunchRows) return [3 /*break*/, 14];
                    return [4 /*yield*/, addLaunchRowsToLandingPage(projectDir, answers.plasmaInstance, projectData)];
                case 13:
                    _a.sent();
                    _a.label = 14;
                case 14:
                    if (!(template.id === "nodejs-console-app-example")) return [3 /*break*/, 16];
                    return [4 /*yield*/, addProjectDetailsToCopiedTemplate_Console(projectDir, answers.plasmaInstance, projectData)];
                case 15:
                    _a.sent();
                    _a.label = 16;
                case 16: return [3 /*break*/, 18];
                case 17:
                    console.log("!!! NOTE !!! You will need to update the template with details from your Plasma account once you create one.");
                    _a.label = 18;
                case 18:
                    // Run the install script...
                    process$1.chdir(projectDir);
                    if (template.installScript) {
                        execSync(template.installScript, { stdio: "inherit" });
                    }
                    // Finished...
                    console.log("Done! Check out the README for information on how to launch your app!");
                    return [2 /*return*/];
            }
        });
    });
}
// Returns the app type options based on the user context...
// Example: If user chooses "Patient" or "Clinician", then they can create a "Web" or "Mobile" app.
function getDevicePlatformOptions(userContext) {
    if (userContext === USER_CONTEXT_BACKEND) {
        return [DEVICE_PLATFORM_SERVER];
    }
    else {
        return [DEVICE_PLATFORM_WEB, DEVICE_PLATFORM_MOBILE];
    }
}
// Returns the template types based on user context (patient/clinician/backend) and platform (web/mobile/server)...
// Example: If user chooses "Backend", then they can create a "Console App".
function getTemplateTypeOptions(userContext, devicePlatform) {
    return templates
        .filter(function (template) { return template.userTypes.includes(userContext); })
        .filter(function (template) { return template.deviceTypes.includes(devicePlatform); })
        .map(function (template) { return template.id; });
}
// Returns the EHR platform options...
function getEhrPlatformOptions() {
    return [
        EHR_PLATFORM_EPIC,
    ];
}
// Get contents of the .env file...
function getEnvFileContents(plasmaInstance, userType, projectData) {
    var lines = [];
    // TODO: This needs to be fixed somewhere...
    var prefix = (userType === USER_CONTEXT_BACKEND) ? "" : "NEXT_PUBLIC_";
    // Add Plasma details...
    lines.push("".concat(prefix, "PLASMA_BASE_URL = \"").concat(plasmaInstance, "\""));
    lines.push("".concat(prefix, "PLASMA_PROJECT_ID = \"").concat(projectData.projectId, "\""));
    projectData.environments.forEach(function (environment) {
        lines.push("".concat(prefix, "PLASMA_ENV_").concat(environment.name.toUpperCase(), " = \"").concat(environment.environmentId, "\""));
    });
    // Add a secret if it exists and this is a backend app...
    if (projectData.projectSecret && userType === USER_CONTEXT_BACKEND) {
        lines.push("PLASMA_CLIENT_SECRET = \"".concat(projectData.projectSecret, "\""));
    }
    return lines.join("\n");
}
// Given a template (e.g. "Console App") and an EHR (e.g. "Epic"), returns the scope required for that template...
function getScopeForTemplate(templateId, platform) {
    var template = templates.find(function (template) { return template.id === templateId; });
    // Try to find scope for the given platform...
    var scope = template.scopesByEhrPlatform[platform];
    if (scope) {
        return scope;
    }
    // If not found, use the default scope...
    return template.defaultScopes;
}
// Add launch rows to the landing page...
function addLaunchRowsToLandingPage(projectDir, plasmaInstance, projectData) {
    return __awaiter(this, void 0, void 0, function () {
        var launchRows, indexFilePath, indexFileContents;
        return __generator(this, function (_a) {
            launchRows = "";
            projectData.environments.forEach(function (environment) {
                // Try to get color based on EHR...
                // TODO: Can we get the actual EHR?
                var color = "blue";
                if (environment.name.toLowerCase().includes("epic")) {
                    color = "red";
                }
                launchRows += getLaunchTableRow(environment.name, plasmaInstance, projectData.projectId, environment.environmentId, color) + "\n\n";
            });
            indexFilePath = path.join(projectDir, "src", "pages", "index.tsx");
            indexFileContents = fse.readFileSync(indexFilePath, "utf8");
            indexFileContents = indexFileContents.replace("{{PLASMA_LAUNCH_ROWS}}", launchRows);
            fse.writeFileSync(indexFilePath, indexFileContents, "utf8");
            return [2 /*return*/];
        });
    });
}
// Initialize the "Console App" template by populating all the code snippets and everything...
function addProjectDetailsToCopiedTemplate_Console(projectDir, plasmaInstance, projectData) {
    return __awaiter(this, void 0, void 0, function () {
        var hasSMART, hasEpic, projectDetails, indexFilePath, indexFileContents, smartExample, epicExample;
        return __generator(this, function (_a) {
            hasSMART = (projectData.environments.some(function (environment) { return environment.name === "SmartHealthIT"; }));
            hasEpic = (projectData.environments.some(function (environment) { return environment.name === "Epic"; }));
            projectDetails = "";
            projectDetails += "const PLASMA_BASE_URL = process.env.PLASMA_BASE_URL ?? \"\";\n";
            projectDetails += "const PLASMA_CLIENT_SECRET = process.env.PLASMA_CLIENT_SECRET ?? \"\";\n";
            projectDetails += "const PLASMA_PROJECT_ID = process.env.PLASMA_PROJECT_ID ?? \"\";\n";
            projectData.environments.forEach(function (environment) {
                projectDetails += "const PLASMA_ENV_".concat(environment.name.toUpperCase(), " = process.env.PLASMA_ENV_").concat(environment.name.toUpperCase(), " ?? \"\";\n");
            });
            indexFilePath = path.join(projectDir, "src", "index.ts");
            indexFileContents = fse.readFileSync(indexFilePath, "utf8");
            indexFileContents = indexFileContents.replace("{{PLASMA_TEMPLATE_DATA}}", projectDetails);
            smartExample = (hasSMART) ? SMART_BACKEND_CONSOLE_CODE_SNIPPET : "";
            indexFileContents = indexFileContents.replace("{{PLASMA_TEMPLATE_SMART_EXAMPLE}}", smartExample);
            epicExample = (hasEpic) ? EPIC_BACKEND_CONSOLE_CODE_SNIPPET : "";
            indexFileContents = indexFileContents.replace("{{PLASMA_TEMPLATE_EPIC_EXAMPLE}}", epicExample);
            // Write the file back...
            fse.writeFileSync(indexFilePath, indexFileContents, "utf8");
            return [2 /*return*/];
        });
    });
}
//
// WORKING WITH PLASMA PROJECTS
//
// Creates a new project and all associated platforms/environments...
function createProjectAndEnvironments(answers, plasmaInstance, plasmaProjectsApiKey, userContext, platforms) {
    return __awaiter(this, void 0, void 0, function () {
        var now, sDate, sTime, sDateAndTime, plasmaApiClient, projectType, returnToUrl, newProject, projectData, _i, platforms_1, platform, platformType, _a, clientId, privateKey, clientSecret, scope, siteId, newPlatform, envName, sandboxData, fhirUrl, authUrl, tokenUrl, newEnvironment;
        return __generator(this, function (_b) {
            switch (_b.label) {
                case 0:
                    now = new Date();
                    sDate = "".concat(now.getFullYear(), "-").concat(now.getMonth() + 1, "-").concat(now.getDate());
                    sTime = "".concat(now.getHours().toString().padStart(2, "0"), ":").concat(now.getMinutes().toString().padStart(2, "0"), ":").concat(now.getSeconds().toString().padStart(2, "0"));
                    sDateAndTime = "".concat(sDate, " ").concat(sTime);
                    plasmaApiClient = new PlasmaProjectsApiClient(plasmaInstance, plasmaProjectsApiKey);
                    // Create a new project...
                    console.log("Creating a new project...");
                    projectType = userContext;
                    returnToUrl = (projectType === "Backend") ? "" : "http://localhost:3000/main";
                    return [4 /*yield*/, plasmaApiClient.createProject("".concat(userContext, " Project; (").concat(now.toISOString(), ")"), "Created by create-plasma-app on ".concat(sDateAndTime), projectType, returnToUrl)];
                case 1:
                    newProject = _b.sent();
                    console.log("Created a new project with ID: ".concat(newProject.id, " (").concat(newProject.name, ")"));
                    projectData = { projectId: "", projectSecret: "", environments: [] };
                    projectData.projectId = newProject.id.toString();
                    projectData.projectSecret = newProject.secret;
                    _i = 0, platforms_1 = platforms;
                    _b.label = 2;
                case 2:
                    if (!(_i < platforms_1.length)) return [3 /*break*/, 7];
                    platform = platforms_1[_i];
                    // Create platform...
                    console.log("Creating platform: " + platform);
                    platformType = getPlatformTypeFromEHRType(platform);
                    _a = getPlatformDataFromPlatform(answers, platform), clientId = _a.clientId, privateKey = _a.privateKey, clientSecret = _a.clientSecret;
                    scope = getScopeForTemplate(answers.templateId, platform);
                    siteId = "";
                    return [4 /*yield*/, plasmaApiClient.createPlatform(newProject.id, platform, platformType, clientId, privateKey, clientSecret, scope, siteId)];
                case 3:
                    newPlatform = _b.sent();
                    console.log("Created platform with ID: ".concat(newPlatform.id, " (").concat(newPlatform.name, ")"));
                    // Create sandbox environment...
                    console.log("Creating Sandbox environment for platform: " + platform);
                    envName = "".concat(platform, " Sandbox");
                    return [4 /*yield*/, getSandboxDataFromPlatform(answers.userContext, platform)];
                case 4:
                    sandboxData = _b.sent();
                    fhirUrl = sandboxData.fhirUrl;
                    authUrl = sandboxData.authUrl;
                    tokenUrl = sandboxData.tokenUrl;
                    return [4 /*yield*/, plasmaApiClient.createEnvironment(newProject.id, newPlatform.id, envName, fhirUrl, authUrl, tokenUrl)];
                case 5:
                    newEnvironment = _b.sent();
                    console.log("Created sandbox environment with ID: ".concat(newEnvironment.id, " (").concat(newEnvironment.name, ")"));
                    // Add to project data...
                    projectData.environments.push({ name: platform, environmentId: newEnvironment.id.toString() });
                    _b.label = 6;
                case 6:
                    _i++;
                    return [3 /*break*/, 2];
                case 7: return [2 /*return*/, projectData];
            }
        });
    });
}
// Given a platform type, returns the correct client ID/secret/etc...
function getPlatformDataFromPlatform(answers, platform) {
    var clientId = "", privateKey = "", clientSecret = "";
    switch (platform) {
        case EHR_PLATFORM_SMART:
            clientId = "";
            privateKey = "";
            clientSecret = "";
            break;
        case EHR_PLATFORM_EPIC:
            clientId = answers.clientId_Epic;
            privateKey = "";
            clientSecret = "";
            // Check private key if it is specified...
            if (!!answers.privateKey_Epic) {
                var privateKeyData = tryReadFileContents(answers.privateKey_Epic);
                if (!privateKeyData.success) {
                    console.log("ERROR: ".concat(privateKeyData.errorMessage));
                }
                privateKey = privateKeyData.contents;
            }
            break;
    }
    return { clientId: clientId, privateKey: privateKey, clientSecret: clientSecret };
}
// Converts an {EHRPlatformTypes} into a {PlatformType}...
function getPlatformTypeFromEHRType(ehrType) {
    switch (ehrType) {
        case EHR_PLATFORM_SMART: return "SmartHealthIT";
        case EHR_PLATFORM_EPIC: return "Epic";
        default: return "Other";
    }
}
//
// TODO: REPLACE THIS WITH SOME API
//
// Given a UserContext (Backend/Patient/Clincian) and a Platform (Epic/Cerner/etc.), returns the sandbox data...
function getSandboxDataFromPlatform(userContext, platform) {
    return __awaiter(this, void 0, void 0, function () {
        var healthSystemId, url, sandboxData;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    healthSystemId = "";
                    switch (platform) {
                        case EHR_PLATFORM_SMART:
                            if (userContext === USER_CONTEXT_BACKEND) {
                                healthSystemId = HEALTH_SYSTEM_ID_SMART_SANDBOX;
                            }
                            else if (userContext === USER_CONTEXT_PATIENT) {
                                healthSystemId = HEALTH_SYSTEM_ID_SMART_SANDBOX_PATIENT;
                            }
                            else if (userContext === USER_CONTEXT_CLINICIAN) {
                                healthSystemId = HEALTH_SYSTEM_ID_SMART_SANDBOX_CLINICIAN;
                            }
                            break;
                        case EHR_PLATFORM_EPIC:
                            healthSystemId = HEALTH_SYSTEM_ID_EPIC_SANDBOX;
                            break;
                        default:
                            healthSystemId = "";
                            break;
                    }
                    // If there wasn't a health system, return blanks...
                    if (!healthSystemId) {
                        return [2 /*return*/, { fhirUrl: "", authUrl: "", tokenUrl: "" }];
                    }
                    url = "".concat(PLASMA_BASE_URL, "/api/plasma/data/health-systems?healthSystemId=").concat(healthSystemId);
                    return [4 /*yield*/, fetch(url)];
                case 1: return [4 /*yield*/, (_a.sent()).json()];
                case 2:
                    sandboxData = _a.sent();
                    if (!sandboxData || sandboxData.length === 0) {
                        return [2 /*return*/, { fhirUrl: "", authUrl: "", tokenUrl: "" }];
                    }
                    return [2 /*return*/, { fhirUrl: sandboxData[0].fhirUrl, authUrl: sandboxData[0].authUrl, tokenUrl: sandboxData[0].tokenUrl }];
            }
        });
    });
}

exports.HEALTH_SYSTEM_ID_EPIC_SANDBOX = HEALTH_SYSTEM_ID_EPIC_SANDBOX;
exports.HEALTH_SYSTEM_ID_SMART_SANDBOX = HEALTH_SYSTEM_ID_SMART_SANDBOX;
exports.HEALTH_SYSTEM_ID_SMART_SANDBOX_CLINICIAN = HEALTH_SYSTEM_ID_SMART_SANDBOX_CLINICIAN;
exports.HEALTH_SYSTEM_ID_SMART_SANDBOX_PATIENT = HEALTH_SYSTEM_ID_SMART_SANDBOX_PATIENT;
//# sourceMappingURL=index.cjs.map
