import * as r4 from "fhir/r4";
import { getParamsFromFHIRResource } from "@/lib/risk-utils";

interface IPatientHeaderProps {
    patient: r4.Patient;
    smokingObservations: r4.Observation[];
    bmiObservations: r4.Observation[];
}

export default function PatientHeader(props: IPatientHeaderProps) {
    const patientParams = getParamsFromFHIRResource(props.patient, props.smokingObservations, props.bmiObservations);

    let smokingStatus = "Unknown";
    if (props.smokingObservations.length > 0) {
        smokingStatus = props.smokingObservations[0].valueCodeableConcept?.text ?? "Unknown";
    }

    let bmi = "Unknown";
    if (props.bmiObservations.length > 0) {
        const bmiValue = props.bmiObservations[0].valueQuantity;
        if (bmiValue) {
            bmi = `${bmiValue.value?.toFixed(2)} ${bmiValue.unit}` ?? "Unknown";
        }
    }

    return (
        <div className="flex flex-col dark:text-gray-300">
            <div className="flex flex-row">
                <div className="flex flex-col w-1/2">
                    <label className="">{patientParams.name}</label>
                    <label className="text-sm">{props.patient.birthDate ?? ""} (~{patientParams.age}y)</label>
                    <label className="text-sm capitalize">{props.patient.gender}</label>
                    <label className="text-sm">{smokingStatus}</label>
                    <label className="text-sm">BMI: {bmi}</label>
                </div>
            </div>
        </div>
    );
}