import * as r4 from "fhir/r4";

// Smoking Statuses...
const SNOMED_FORMER_SMOKER = "8517006";
const SNOMED_NEVER_SMOKER = "266919005";
const SNOMED_CURRENT_SMOKER = "77176002";   // Could be many others

export function getParamsFromFHIRResource(patient: r4.Patient, smokingStatuses: r4.Observation[], bmiObservations: r4.Observation[]): { name: string, gender: "male" | "female", age: number, smokingStatus: "never" | "past" | "current", bmi: number } {
    // Patient data...
    const firstName = patient.name?.[0]?.given?.[0] ?? "";
    const lastName = patient.name?.[0]?.family ?? "";
    const name = `${firstName} ${lastName}`;
    const gender = patient.gender === "female" ? "female" : "male";
    const dob = patient.birthDate ?? "";
    const age = new Date().getFullYear() - new Date(dob).getFullYear();

    // Smoking status...
    let smokingStatus: "never" | "past" | "current" = "never";
    if (smokingStatuses.length > 0) {
        const value = smokingStatuses[0].valueCodeableConcept?.coding?.[0]?.code;
        if (value === SNOMED_FORMER_SMOKER) { smokingStatus = "past"; } 
        if (value === SNOMED_NEVER_SMOKER) { smokingStatus = "never"; }
        if (value === SNOMED_CURRENT_SMOKER) { smokingStatus = "current"; }
    }

    // BMI...
    let bmi = 0;
    if (bmiObservations.length > 0) {
        bmi = bmiObservations[0].valueQuantity?.value ?? 0;
    }

    return { name, gender, age, smokingStatus, bmi };
}